/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/

//Version of PCB: 16.2 31 January 2020

$fs = 0.1; //Sets the number of fragments used in a circle
 
// Parameters and constants for a Container for Lock Controller V16
//Assumes mounting hole screws are M2 and attachment bolt is M3

Tolerancemm = 0.2; //3D Printing tolerance
Inch2mm    = 25.4;

//Connector holes - all in millimetres
//Along the top (x = from left edge of PCB in inches,
//               y = 0 from to of PCB in inches,
//               z = height of centre above PCB in mm,
//               d = diameter in mm)
LED_Orange    = [ 0.52 * Inch2mm, 0, 2.54]; LED_Orange_d  = 4.0;
//-------------------------
//z = 14.0 for socketed Nano
//Nano          = [ 1.100 * Inch2mm, 0, 14.0]; Nano_d        = 15.;
//z = 6.65 for soldered Nano
Nano          = [ 1.100 * Inch2mm, 0, 6.65]; Nano_d        = 15.;
//-------------------------
DIN6          = [ 2.105 * Inch2mm, 0, 11.0]; DIN6_d        = 21.5;
Barrel_Jack   = [ 2.830 * Inch2mm, 0, 7.50]; Barrel_Jack_d = 12.;
LED_Red       = [ 3.160 * Inch2mm, 0, 2.54]; LED_Red_d     = 4.0;
//Along the side (x = 0)
RJ45          = [ 0, 1.19 * Inch2mm, -1.60]; RJ45_y_z      = 15.;
AudioJack5    = [ 0, 2.4  * Inch2mm, -3.54]; AudioJack5_d  = 15.;
AudioJack6    = [ 0, 3.1  * Inch2mm, -3.54]; AudioJack6_d  = 15.;
//
PCBX         = 3.6; //X dimension in inches
PCBY         = 3.8; //Y dimension in inches
PCBZ         = 0.8; //Height of highest component (DIN6) in inches
PCBT         = 1.6; //Z dimension in mm
//
ClearanceX   = 0.15; //Distance from PCB edge to outside of box in inches
ClearanceY   = 0.15; //Distance from PCB edge to outside of box in inches
ClearanceZ   = 0.1;  //Clearance above DIN6 plug in inches
VentHoleR    = PCBZ / 8; //Diameter of the vent holes
CentreVentHoleRmm  = 17; //Diameter of the centre vent hole for V15
ContainerT   = 0.1; //Wall thickness in inches
HoleDmm      = 4.0 + Tolerancemm * 2;  //Diameter of mounting hole in mm for M4 bolt
Nutmm        = 7.0; //Size of M4 Nut
ScrewHoleRmm = 1.9 - Tolerancemm * 2;//Hole radius in mm for an M2 screw
    //4g screw is 2.86 mm diameter
ScrewPostRmm = ScrewHoleRmm + 4; //Post radius in mm
ScrewPostO   = 0.15; //Offset from PCB edge in inches
LidPostRmm   = ScrewHoleRmm + 2; //For Lid mount
ScrewPostZ   = 0.5;  //Height of screw post in inches
BoxColour    = [ 1, 1, .5];
AlignmentPlateY = 1.4; //Slots into back of rail
RetainerX    = 2.5;  //Retainer width
RetainerY    = 1.15; //Retainer Y dimension in inches
RetainerT    = 0.2;  //Retainer plate thickness in inches
RetainerZ    = 0.2;  //Height of retainer ridge in inches
RetainerRidgeSep = 2.2;  //Distance between ridges in inches

//Calculate dimensions
ContainerX = PCBX + ClearanceX * 2;  //X dimension in inches
ContainerY = PCBY + ClearanceY * 2;  //Y dimension in inches - added 1Mar2020
ContainerZ = ScrewPostZ + PCBZ + ClearanceZ + ContainerT * 2;//Z dimension in inches
//Convert dimensions to mm
PCBXmm       = PCBX       * Inch2mm; //mm
PCBYmm       = PCBY       * Inch2mm; //mm
ClearanceXmm = ClearanceX * Inch2mm; //Distance from PCB edge to outside in mm
ClearanceZmm = ClearanceZ * Inch2mm; //Clearance for DIN6 plug in mm
VentHoleRmm  = VentHoleR  * Inch2mm; //Diameter of the vent holes in mm
ContainerXmm = ContainerX * Inch2mm; //mm
ContainerYmm = ContainerY * Inch2mm; //mm
ContainerZmm = ContainerZ * Inch2mm; //mm
ContainerTmm = ContainerT * Inch2mm; //mm
ScrewPostZmm = ScrewPostZ * Inch2mm; //mm
ScrewPostOmm = ScrewPostO * Inch2mm; //mm
AlignmentPlateYmm = AlignmentPlateY * Inch2mm;
RetainerXmm = RetainerX * Inch2mm; //Retainer width
RetainerYmm = RetainerY * Inch2mm; //Retainer Y dimension in inches
RetainerTmm = RetainerT * Inch2mm; //Retainer Z dimension in inches
RetainerZmm = RetainerZ * Inch2mm; //Height of retainer ridge in mm
RetainerRidgeSepmm = RetainerRidgeSep * Inch2mm; //Distance between ridges in mm
//Placement of the screw holes for the lid
XLid = ContainerXmm / 2 - ScrewHoleRmm;
YLid = ContainerYmm / 2 - ScrewHoleRmm;
